<?php

namespace Drupal\Tests\comscore_direct\Functional;

use Drupal\Tests\BrowserTestBase;
use Drupal\Core\StringTranslation\StringTranslationTrait;

/**
 * Comscore Direct tests.
 *
 * @group comscore_direct
 *
 * Class ComscoreDirect
 * @package Drupal\Tests\boxout\Functional
 */
class ComscoreDirect extends BrowserTestBase {

  use StringTranslationTrait;

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * {@inheritdoc}
   */
  protected $profile = 'standard';

  /**
   * Modules to enable.
   *
   * @var array
   */
  protected static $modules = ['comscore_direct'];

  /**
   * A user with the 'administer filters' permission.
   *
   * @var \Drupal\user\UserInterface
   */
  protected $adminUser;

  /**
   * {@inheritdoc}
   */
  protected function setUp() {
    parent::setUp();

    // Create admin user.
    $this->adminUser = $this->drupalCreateUser([
      'access administration pages',
      'administer comscore direct',
    ]);
  }

  /**
   * Test Comscore.
   */
  function testComscore() {
    $this->drupalLogin($this->adminUser);
    $this->drupalGet('admin/config/services/comscore_direct');
    $this->submitForm([
      'site_id' => '123456',
      'genre' => 'test_genre',
      'package' => 'test_package',
      'clientseg' => 'test_segment',
    ], $this->t('Save configuration'));
    $this->assertRaw($this->t('The configuration options have been saved'));

    $this->drupalGet('<front>');

    // Test markup.
    $this->assertPattern('|_comscore.push\({.*"c1":"2"|');
    $this->assertPattern('|_comscore.push\({.*"c2":"123456"|');
    $this->assertPattern('|_comscore.push\({.*"c3":""|');
    $this->assertPattern('|_comscore.push\({.*"c5":"test_genre"|');
    $this->assertPattern('|_comscore.push\({.*"c6":"test_package"|');
    $this->assertPattern('|_comscore.push\({.*"c15":"test_segment"|');
    $this->assertRaw('//b.scorecardresearch.com/p?c1=2&amp;c2=123456&amp;c3=&amp;c4=http');
    $this->assertRaw('c5=test_genre&amp;c6=test_package&amp;c15=test_segment&amp;cv=2&amp;cj=1');
  }
}
